'use strict';

var queryPersistClientCore = require('@tanstack/query-persist-client-core');
var web = require('solid-js/web');
var solidJs = require('solid-js');
var solidQuery = require('@tanstack/solid-query');

// src/index.ts
exports.PersistQueryClientProvider = (props) => {
  const [isRestoring, setIsRestoring] = solidJs.createSignal(true);
  const options = solidJs.createMemo(() => ({
    ...props.persistOptions,
    queryClient: props.client
  }));
  solidJs.createEffect(() => {
    setIsRestoring(true);
    queryPersistClientCore.persistQueryClientRestore(options()).then(async () => {
      try {
        await props.onSuccess?.();
      } finally {
        setIsRestoring(false);
      }
    });
  });
  solidJs.createEffect(() => {
    let unsubscribe = () => {
    };
    if (!isRestoring()) {
      unsubscribe = queryPersistClientCore.persistQueryClientSubscribe(options());
    }
    solidJs.onCleanup(() => unsubscribe());
  });
  return web.createComponent(solidQuery.QueryClientProvider, {
    get client() {
      return props.client;
    },
    get children() {
      return web.createComponent(solidQuery.IsRestoringProvider, {
        value: isRestoring,
        get children() {
          return props.children;
        }
      });
    }
  });
};

Object.keys(queryPersistClientCore).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return queryPersistClientCore[k]; }
  });
});
