import { persistQueryClientRestore, persistQueryClientSubscribe } from '@tanstack/query-persist-client-core';
export * from '@tanstack/query-persist-client-core';
import { createComponent } from 'solid-js/web';
import { createSignal, createMemo, createEffect, onCleanup } from 'solid-js';
import { QueryClientProvider, IsRestoringProvider } from '@tanstack/solid-query';

// src/index.ts
var PersistQueryClientProvider = (props) => {
  const [isRestoring, setIsRestoring] = createSignal(true);
  const options = createMemo(() => ({
    ...props.persistOptions,
    queryClient: props.client
  }));
  createEffect(() => {
    setIsRestoring(true);
    persistQueryClientRestore(options()).then(async () => {
      try {
        await props.onSuccess?.();
      } finally {
        setIsRestoring(false);
      }
    });
  });
  createEffect(() => {
    let unsubscribe = () => {
    };
    if (!isRestoring()) {
      unsubscribe = persistQueryClientSubscribe(options());
    }
    onCleanup(() => unsubscribe());
  });
  return createComponent(QueryClientProvider, {
    get client() {
      return props.client;
    },
    get children() {
      return createComponent(IsRestoringProvider, {
        value: isRestoring,
        get children() {
          return props.children;
        }
      });
    }
  });
};

export { PersistQueryClientProvider };
